#ifndef NT2_INCLUDE_FUNCTIONS_FREXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FREXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/frexp.hpp>

#endif
